@@ -59,12 +59,12 @@ fn logic(game_state: &mut GameState) {
     let mut place_actor = false;
     let mut prev_preset = false;
     let mut next_preset = false;
-    for keyboard_input in &game_state.keyboard_events {
+    for keyboard_event in &game_state.keyboard_events {
         if let KeyboardInput {
             scan_code: _,
             key_code: Some(key_code),
             state,
-        } = keyboard_input
+        } = keyboard_event
         {
             if *state == ElementState::Pressed {
                 match key_code {
@@ -112,7 +112,7 @@ fn logic(game_state: &mut GameState) {
                 continue;
             }
             println!(
-                "    let a = game.game_state_mut().add_actor(\"{}\", ActorPreset::{:?}); a.translation = Vec2::new({:.1}, {:.1}); a.rotation = {:.8}; a.scale = {:.8}; a.layer = {:.8};",
+                "    let a = game.game_state_mut().add_actor(\"{}\", ActorPreset::{:?}); a.translation = Vec2::new({:.1}, {:.1}); a.rotation = {:.8}; a.scale = {:.8}; a.layer = {:.8}; a.collision = true;",
                 actor.label,
                 actor.preset.unwrap(),
                 actor.translation.x,
@@ -145,7 +145,7 @@ fn logic(game_state: &mut GameState) {
         }
 
         // Handle translation via mouse location
-        for cursor_moved in &game_state.cursor_moved_events {
+        for cursor_moved in &game_state.mouse_location_events {
             actor.translation = cursor_moved.position;
         }
         // Handle rotation via mouse clicks
